##  Calculate the Total Cost of Ownership for Applications
The total cost of ownership summarizes all costs for an application, like licensing, maintenance, and support costs. The data for licensing, maintenance and support are provided either through the survey or integration. The total cost of ownership calculation works automatically.
![Screenshot of fact sheet details showing the application cost fields](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio4e175ae78c36445eb2561f72ad2eaa41_HiRes.png)
